<?php

namespace Kscc\Slider\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Kscc\Slider\Http\Requests\SliderRequest;
use Kscc\Slider\Interfaces\SliderRepositoryInterface;
use Kscc\Slider\Models\Slider;
use Kscc\Slider\Forms\Slider as Form;

/**
 * APIController  class for slider.
 */
class SliderAPIController extends BaseController
{

    /**
     * Initialize slider resource controller.
     *
     * @param type SliderRepositoryInterface $slider
     *
     * @return null
     */
    public function __construct(SliderRepositoryInterface $slider)
    {
        parent::__construct();
        $this->repository = $slider;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Kscc\Slider\Repositories\Criteria\SliderResourceCriteria::class);
    }

    /**
     * Display a list of slider.
     *
     * @return Response
     */
    public function index(SliderRequest $request)
    {
        return $this->repository
            ->setPresenter(\Kscc\Slider\Repositories\Presenter\SliderPresenter::class)
            ->paginate();
    }

    /**
     * Display slider.
     *
     * @param Request $request
     * @param Model   $slider
     *
     * @return Response
     */
    public function show(SliderRequest $request, Slider $slider)
    {
        return $slider->setPresenter(\Kscc\Slider\Repositories\Presenter\SliderListPresenter::class);
        ;
    }

    /**
     * Create new slider.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SliderRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('slider::slider.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('slider/slider/' . $slider->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('slider/slider');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the slider.
     *
     * @param Request $request
     * @param Model   $slider
     *
     * @return Response
     */
    public function update(SliderRequest $request, Slider $slider)
    {
        try {
            $data = $request->all();

            $slider->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('slider::slider.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('slider/slider/' . $slider->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('slider/slider/' . $slider->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the slider.
     *
     * @param Model   $slider
     *
     * @return Response
     */
    public function destroy(SliderRequest $request, Slider $slider)
    {
        try {
            $slider->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('slider::slider.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('slider/slider/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('slider/slider/' . $slider->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
